use StressTests
GO
ALTER DATABASE StressTests
    SET READ_COMMITTED_SNAPSHOT OFF
GO

CREATE TABLE Data.Users(UserId INT NOT NULL, 
 FirstName VARCHAR(8) NOT NULL, 
 LastName VARCHAR(8) NOT NULL, 
 Position VARCHAR(20) NOT NULL,
 LotsOfComments CHAR(5000) NOT NULL,
 CONSTRAINT PK_Users PRIMARY KEY(UserId))
GO
CREATE TABLE Data.Tickets(TicketId INT NOT NULL, 
  AssignedTo INT NOT NULL, 
  Priority VARCHAR(10) NOT NULL,
  Status VARCHAR(10) NOT NULL,
  LotsOfComments CHAR(5000) NOT NULL,
  CONSTRAINT PK_Tickets PRIMARY KEY(TicketId),
  CONSTRAINT FK_Tickets_Users FOREIGN KEY(AssignedTo) REFERENCES Data.Users(UserId)
)
GO
CREATE INDEX Tickets_AssignedTo ON Data.Tickets(AssignedTo)
GO
CREATE PROCEDURE Readers.SelectTotalTickets
AS
SELECT COUNT(*) AS cnt
  FROM Data.Tickets 
GO
CREATE PROCEDURE Writers.ReassignTicket
	@TicketId INT,
    @AssignedTo INT
AS
UPDATE Data.Tickets SET AssignedTo = @AssignedTo
  WHERE TicketId = @TicketId
GO

CREATE PROCEDURE Writers.RepopulateTickets
AS
DECLARE @i INT 
SET NOCOUNT ON
DELETE FROM Data.Tickets
SET @i = 0
WHILE @i<10000 BEGIN
  INSERT INTO Data.Tickets(TicketId, AssignedTo, Priority, Status, LotsOfComments)
    VALUES(@i, @i, CASE WHEN @i % 3 = 1 THEN 'High' 
      WHEN @i % 3 = 2 THEN 'Medium'
      ELSE 'Low' END, 'Open', '')
  SET @i = @i + 1
END
GO
